@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 1999-2007  Free Software Foundation, Inc.
+ * Copyright (C) 1999-2010  Free Software Foundation, Inc.
  *
  * This file is part of GNU gengetopt
  *
@@ -30,6 +30,7 @@
 #include <algorithm> // for pair
 
 #include <fstream>
+#include <sstream>
 
 extern "C"
 {
@@ -40,7 +41,6 @@ extern "C"
 #include "ggo_options.h"
 
 #include "gm.h"
-#include "my_sstream.h"
 
 #include "groups.h"
 #include "skels/option_arg.h"
@@ -68,6 +68,7 @@ extern "C"
 #include "skels/init_args_info.h"
 #include "skels/custom_getopt_gen.h"
 #include "skels/check_modes.h"
+#include "skels/enum_decl.h"
 #include "gm_utils.h"
 #include "fileutils.h"
 
@@ -82,8 +83,7 @@ extern "C"
 #define PARSER_NAME_PREFIX (c_source_gen_class::parser_name + "_")
 #define OPTION_VALUES_NAME(n) (PARSER_NAME_PREFIX + n + "_values")
 
-using std::endl;
-using std::set;
+using namespace std;
 
 extern char * gengetopt_package;
 extern char * gengetopt_version;
@@ -425,18 +425,20 @@ CmdlineParserCreator::generate_enum_types(ostream &stream,
                             __FILE__, __LINE__);
             abort ();
         }
-        stream << "enum enum_" << opt->var_arg << " { ";
+        ostringstream enum_values;
+        enum_decl_gen_class enum_gen;
+        enum_gen.set_var_arg(opt->var_arg);
         for (AcceptedValues::const_iterator it = opt->acceptedvalues->begin();
             it != opt->acceptedvalues->end(); ++it) {
+            enum_values << ", ";
             // the first enum element is set to 0
-            if (it != opt->acceptedvalues->begin())
-                stream << ", ";
-            stream << from_value_to_enum(opt->var_arg, *it);
+            enum_values << from_value_to_enum(opt->var_arg, *it);
             if (it == opt->acceptedvalues->begin())
-                stream << " = 0 ";
+                enum_values << " = 0";
 
         }
-        stream << " };" << endl;
+        enum_gen.set_enum_values(enum_values.str());
+        enum_gen.generate_enum_decl(stream);
     }
   }
 }
@@ -653,7 +655,9 @@ CmdlineParserCreator::generate_usage_string(bool use_config_package)
   FIX_UNUSED (use_config_package);
   // if specified by the programmer, the usage string has the precedence
   if (gengetopt_usage) {
-    return gengetopt_usage;
+      string wrapped_usage;
+      wrap_cstr(wrapped_usage, 0, 0, gengetopt_usage);
+      return wrapped_usage;
   }
 
   struct gengetopt_option * opt;
@@ -1549,7 +1553,7 @@ CmdlineParserCreator::generate_clear_arg(ostream &stream, unsigned int indent)
         if (opt->default_given)
             clear_arg.set_value(from_value_to_enum(opt->var_arg, opt->default_string));
         else
-            clear_arg.set_value("-1");
+            clear_arg.set_value(string(opt->var_arg) + "__NULL");
       }
       else if (opt->default_given)
         {
