@@ -15,13 +15,15 @@
 #endif
 
 #include <string.h>
+#include <sstream>
 
 #include "gm_utils.h"
-#include "my_sstream.h"
 #include "ggo_options.h"
 #include "argsdef.h"
 #include "groups.h"
 
+using namespace std;
+
 extern groups_collection_t gengetopt_groups;
 
 char *
@@ -162,7 +164,7 @@ bool has_options_with_type() {
 
     for (gengetopt_option_list::iterator it = gengetopt_options.begin(); it
             != gengetopt_options.end() && (opt = *it); ++it)
-        if (opt->type)
+        if (opt->type && opt->type != ARG_FLAG)
             return true;
 
     return false;
@@ -248,25 +250,23 @@ bool has_values() {
     return false;
 }
 
-inline static int char_is_newline(const string &buf, int &num_of_newlines) {
+int not_newlines(const string &buf, int &num_of_newlines) {
     num_of_newlines = 0;
+    // searches for the first non newline char
     string::size_type notnewline = buf.find_first_not_of("\r\n");
 
     if (notnewline == string::npos) {
+        // a string made only of newlines
         num_of_newlines = buf.size();
         return num_of_newlines;
     }
 
     if (notnewline) {
+        // everything before the non newline char is a newline
         num_of_newlines = notnewline;
         return notnewline;
     }
 
-    if (buf.size() > 1 && buf[0] == '\\' && buf[1] == 'n') {
-        num_of_newlines = 1;
-        return 2;
-    }
-
     return 0;
 }
 
@@ -284,7 +284,7 @@ void wrap_cstr(string& wrapped, unsigned int from_column,
     while (*out_buf) {
         // check for a new line
         if (*out_buf) {
-            if ((newline_chars = char_is_newline(out_buf, num_of_newlines))) {
+            if ((newline_chars = not_newlines(out_buf, num_of_newlines))) {
                 for (int i = 1; i <= num_of_newlines; ++i)
                     stream << "\\n";
 
@@ -302,9 +302,8 @@ void wrap_cstr(string& wrapped, unsigned int from_column,
             }
         }
         // search next whitespace, i.e., next word
-        while ((*out_buf) && (*out_buf != ' ') && !char_is_newline(out_buf,
-                num_of_newlines)) {
-            // num_of_newlines is not used.
+        while ((*out_buf) && (*out_buf != ' ') &&
+                !not_newlines(out_buf, num_of_newlines)) {
             next_word += *out_buf++;
             next_space++;
         }
