@@ -93,6 +93,16 @@ bool is_numeric(const gengetopt_option *opt);
  */
 void wrap_cstr (string &wrapped, unsigned int from_column, unsigned int second_indent, const string &orig);
 
+/**
+ * Searches for characters which are not newlines.
+ *
+ * @param buf where to search for new characters
+ * @param num_of_newlines where the number of newlines
+ * before the first non newline char will be stored
+ * @return the position in the string after the (possible) new line char
+ */
+int not_newlines(const string &buf, int &num_of_newlines);
+
 /**
  * Function object to print something into a stream (to be used with for_each)
  */
