@@ -78,8 +78,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
-
-#include "my_sstream.h"
+#include <string>
+#include <sstream>
 
 #include "acceptedvalues.h"
 
@@ -99,10 +99,15 @@ static int gengetopt_purpose_given = 0;
 static int gengetopt_usage_given = 0;
 static int gengetopt_description_given = 0;
 
+/// the last option parsed
+static gengetopt_option *current_option = 0;
+
 extern int yylex (void) ;
 
 //#define YYERROR_VERBOSE 1
 
+using namespace std;
+
 void check_result(int o, gengetopt_option *opt)
 {
   if (o)
@@ -192,7 +197,7 @@ struct multiple_size
 
 
 /* Line 189 of yacc.c  */
-#line 196 "../../src/parser.cc"
+#line 201 "../../src/parser.cc"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -301,7 +306,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 144 "../../src/parser.yy"
+#line 149 "../../src/parser.yy"
 
     char   *str;
     char    chr;
@@ -314,7 +319,7 @@ typedef union YYSTYPE
 
 
 /* Line 214 of yacc.c  */
-#line 318 "../../src/parser.cc"
+#line 323 "../../src/parser.cc"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -339,7 +344,7 @@ typedef struct YYLTYPE
 
 
 /* Line 264 of yacc.c  */
-#line 343 "../../src/parser.cc"
+#line 348 "../../src/parser.cc"
 
 #ifdef short
 # undef short
@@ -652,13 +657,13 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   205,   205,   207,   212,   213,   214,   215,   216,   217,
-     218,   219,   220,   221,   222,   223,   224,   229,   249,   269,
-     289,   309,   330,   337,   344,   351,   362,   373,   392,   411,
-     433,   436,   442,   447,   452,   457,   462,   467,   472,   477,
-     482,   487,   495,   500,   505,   510,   514,   515,   519,   520,
-     521,   525,   526,   530,   531,   535,   536,   540,   541,   545,
-     546,   550,   554,   555,   556,   557,   558
+       0,   210,   210,   212,   217,   218,   219,   220,   221,   222,
+     223,   224,   225,   226,   227,   228,   229,   234,   254,   274,
+     294,   314,   335,   342,   359,   366,   377,   388,   408,   427,
+     449,   452,   458,   463,   468,   473,   478,   483,   488,   493,
+     498,   503,   511,   516,   521,   526,   530,   531,   535,   536,
+     537,   541,   542,   546,   547,   551,   552,   556,   557,   561,
+     562,   566,   570,   571,   572,   573,   574
 };
 #endif
 
@@ -1672,7 +1677,7 @@ yyreduce:
         case 17:
 
 /* Line 1455 of yacc.c  */
-#line 230 "../../src/parser.yy"
+#line 235 "../../src/parser.yy"
     {
 	      if (gengetopt_package_given)
 		{
@@ -1694,7 +1699,7 @@ yyreduce:
   case 18:
 
 /* Line 1455 of yacc.c  */
-#line 250 "../../src/parser.yy"
+#line 255 "../../src/parser.yy"
     {
 	      if (gengetopt_version_given)
 		{
@@ -1716,7 +1721,7 @@ yyreduce:
   case 19:
 
 /* Line 1455 of yacc.c  */
-#line 270 "../../src/parser.yy"
+#line 275 "../../src/parser.yy"
     {
 	      if (gengetopt_purpose_given)
 		{
@@ -1738,7 +1743,7 @@ yyreduce:
   case 20:
 
 /* Line 1455 of yacc.c  */
-#line 290 "../../src/parser.yy"
+#line 295 "../../src/parser.yy"
     {
 	      if (gengetopt_description_given)
 		{
@@ -1760,7 +1765,7 @@ yyreduce:
   case 21:
 
 /* Line 1455 of yacc.c  */
-#line 310 "../../src/parser.yy"
+#line 315 "../../src/parser.yy"
     {
       if (gengetopt_usage_given)
       {
@@ -1782,7 +1787,7 @@ yyreduce:
   case 22:
 
 /* Line 1455 of yacc.c  */
-#line 331 "../../src/parser.yy"
+#line 336 "../../src/parser.yy"
     {
                 gengetopt_set_section ((yyvsp[(2) - (3)].str), (yyvsp[(3) - (3)].str));
               }
@@ -1791,16 +1796,26 @@ yyreduce:
   case 23:
 
 /* Line 1455 of yacc.c  */
-#line 338 "../../src/parser.yy"
+#line 343 "../../src/parser.yy"
     {
-  gengetopt_set_text((yyvsp[(2) - (2)].str));
+            	if (current_option) {
+            		std::string current_option_text;
+            		if (current_option->text_after) {
+            			current_option_text = std::string(current_option->text_after) + (yyvsp[(2) - (2)].str);
+            			current_option->text_after = strdup(current_option_text.c_str()); 
+            		} else {
+	            		current_option->text_after = strdup((yyvsp[(2) - (2)].str));
+	            	}
+            	} else {
+					gengetopt_set_text((yyvsp[(2) - (2)].str));
+  				}
             }
     break;
 
   case 24:
 
 /* Line 1455 of yacc.c  */
-#line 345 "../../src/parser.yy"
+#line 360 "../../src/parser.yy"
     {
   gengetopt_set_args((yyvsp[(2) - (2)].str));
             }
@@ -1809,7 +1824,7 @@ yyreduce:
   case 25:
 
 /* Line 1455 of yacc.c  */
-#line 352 "../../src/parser.yy"
+#line 367 "../../src/parser.yy"
     {
               if (gengetopt_add_group ((yyvsp[(2) - (4)].str), (yyvsp[(3) - (4)].str), (yyvsp[(4) - (4)].boolean)))
                 {
@@ -1822,7 +1837,7 @@ yyreduce:
   case 26:
 
 /* Line 1455 of yacc.c  */
-#line 363 "../../src/parser.yy"
+#line 378 "../../src/parser.yy"
     {
               if (gengetopt_add_mode ((yyvsp[(2) - (3)].str), (yyvsp[(3) - (3)].str)))
                 {
@@ -1835,7 +1850,7 @@ yyreduce:
   case 27:
 
 /* Line 1455 of yacc.c  */
-#line 375 "../../src/parser.yy"
+#line 390 "../../src/parser.yy"
     {
           (yyvsp[(5) - (5)].gengetopt_option)->filename = gengetopt_input_filename;
           (yyvsp[(5) - (5)].gengetopt_option)->linenum = (yylsp[(1) - (5)]).first_line;
@@ -1849,13 +1864,14 @@ yyreduce:
 	      o = gengetopt_add_option ((yyvsp[(5) - (5)].gengetopt_option));
 	      check_result(o, (yyvsp[(5) - (5)].gengetopt_option));
 	      check_error;
+	      current_option = (yyvsp[(5) - (5)].gengetopt_option);
 	    }
     break;
 
   case 28:
 
 /* Line 1455 of yacc.c  */
-#line 394 "../../src/parser.yy"
+#line 410 "../../src/parser.yy"
     {
           (yyvsp[(5) - (5)].gengetopt_option)->filename = gengetopt_input_filename;
           (yyvsp[(5) - (5)].gengetopt_option)->linenum = (yylsp[(1) - (5)]).first_line;
@@ -1875,7 +1891,7 @@ yyreduce:
   case 29:
 
 /* Line 1455 of yacc.c  */
-#line 413 "../../src/parser.yy"
+#line 429 "../../src/parser.yy"
     {
           (yyvsp[(5) - (5)].gengetopt_option)->filename = gengetopt_input_filename;
           (yyvsp[(5) - (5)].gengetopt_option)->linenum = (yylsp[(1) - (5)]).first_line;
@@ -1895,7 +1911,7 @@ yyreduce:
   case 31:
 
 /* Line 1455 of yacc.c  */
-#line 437 "../../src/parser.yy"
+#line 453 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
 			  	(yyval.gengetopt_option)->required = (yyvsp[(2) - (2)].boolean);
@@ -1906,7 +1922,7 @@ yyreduce:
   case 32:
 
 /* Line 1455 of yacc.c  */
-#line 443 "../../src/parser.yy"
+#line 459 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
 			  	(yyval.gengetopt_option)->type = (yyvsp[(2) - (2)].argtype);
@@ -1916,7 +1932,7 @@ yyreduce:
   case 33:
 
 /* Line 1455 of yacc.c  */
-#line 448 "../../src/parser.yy"
+#line 464 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
 			  	(yyval.gengetopt_option)->type_str = strdup((yyvsp[(4) - (4)].str));
@@ -1926,7 +1942,7 @@ yyreduce:
   case 34:
 
 /* Line 1455 of yacc.c  */
-#line 453 "../../src/parser.yy"
+#line 469 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
 			  	(yyval.gengetopt_option)->details = strdup((yyvsp[(4) - (4)].str));
@@ -1936,7 +1952,7 @@ yyreduce:
   case 35:
 
 /* Line 1455 of yacc.c  */
-#line 458 "../../src/parser.yy"
+#line 474 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
 			  	(yyval.gengetopt_option)->acceptedvalues = (yyvsp[(4) - (4)].ValueList);
@@ -1946,7 +1962,7 @@ yyreduce:
   case 36:
 
 /* Line 1455 of yacc.c  */
-#line 463 "../../src/parser.yy"
+#line 479 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
 			  	(yyval.gengetopt_option)->default_string = strdup((yyvsp[(4) - (4)].str));
@@ -1956,7 +1972,7 @@ yyreduce:
   case 37:
 
 /* Line 1455 of yacc.c  */
-#line 468 "../../src/parser.yy"
+#line 484 "../../src/parser.yy"
     {
                 (yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
                 (yyval.gengetopt_option)->group_value = strdup((yyvsp[(4) - (4)].str));
@@ -1966,7 +1982,7 @@ yyreduce:
   case 38:
 
 /* Line 1455 of yacc.c  */
-#line 473 "../../src/parser.yy"
+#line 489 "../../src/parser.yy"
     {
                 (yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
                 (yyval.gengetopt_option)->mode_value = strdup((yyvsp[(4) - (4)].str));
@@ -1976,7 +1992,7 @@ yyreduce:
   case 39:
 
 /* Line 1455 of yacc.c  */
-#line 478 "../../src/parser.yy"
+#line 494 "../../src/parser.yy"
     {
                 (yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
                 (yyval.gengetopt_option)->dependon = strdup((yyvsp[(4) - (4)].str));
@@ -1986,7 +2002,7 @@ yyreduce:
   case 40:
 
 /* Line 1455 of yacc.c  */
-#line 483 "../../src/parser.yy"
+#line 499 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
 			  	(yyval.gengetopt_option)->arg_is_optional = true;
@@ -1996,7 +2012,7 @@ yyreduce:
   case 41:
 
 /* Line 1455 of yacc.c  */
-#line 488 "../../src/parser.yy"
+#line 504 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (3)].gengetopt_option);
 			  	(yyval.gengetopt_option)->multiple = true;
@@ -2009,7 +2025,7 @@ yyreduce:
   case 42:
 
 /* Line 1455 of yacc.c  */
-#line 496 "../../src/parser.yy"
+#line 512 "../../src/parser.yy"
     {
           (yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
           (yyval.gengetopt_option)->type = ARG_FLAG;
@@ -2019,7 +2035,7 @@ yyreduce:
   case 43:
 
 /* Line 1455 of yacc.c  */
-#line 501 "../../src/parser.yy"
+#line 517 "../../src/parser.yy"
     {
           (yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
           (yyval.gengetopt_option)->hidden = true;
@@ -2029,7 +2045,7 @@ yyreduce:
   case 44:
 
 /* Line 1455 of yacc.c  */
-#line 506 "../../src/parser.yy"
+#line 522 "../../src/parser.yy"
     {
           (yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
           (yyval.gengetopt_option)->flagstat = (yyvsp[(2) - (2)].boolean);
@@ -2039,161 +2055,161 @@ yyreduce:
   case 45:
 
 /* Line 1455 of yacc.c  */
-#line 510 "../../src/parser.yy"
+#line 526 "../../src/parser.yy"
     { (yyval.gengetopt_option) = new gengetopt_option; }
     break;
 
   case 46:
 
 /* Line 1455 of yacc.c  */
-#line 514 "../../src/parser.yy"
+#line 530 "../../src/parser.yy"
     { (yyval.boolean) = 1; }
     break;
 
   case 47:
 
 /* Line 1455 of yacc.c  */
-#line 515 "../../src/parser.yy"
+#line 531 "../../src/parser.yy"
     { (yyval.boolean) = 0; }
     break;
 
   case 48:
 
 /* Line 1455 of yacc.c  */
-#line 519 "../../src/parser.yy"
+#line 535 "../../src/parser.yy"
     { (yyval.boolean) = 0; }
     break;
 
   case 49:
 
 /* Line 1455 of yacc.c  */
-#line 520 "../../src/parser.yy"
+#line 536 "../../src/parser.yy"
     { (yyval.boolean) = 1; }
     break;
 
   case 50:
 
 /* Line 1455 of yacc.c  */
-#line 521 "../../src/parser.yy"
+#line 537 "../../src/parser.yy"
     { (yyval.boolean) = 0; }
     break;
 
   case 51:
 
 /* Line 1455 of yacc.c  */
-#line 525 "../../src/parser.yy"
+#line 541 "../../src/parser.yy"
     { (yyval.boolean) = 1; }
     break;
 
   case 52:
 
 /* Line 1455 of yacc.c  */
-#line 526 "../../src/parser.yy"
+#line 542 "../../src/parser.yy"
     { (yyval.boolean) = 0; }
     break;
 
   case 53:
 
 /* Line 1455 of yacc.c  */
-#line 530 "../../src/parser.yy"
+#line 546 "../../src/parser.yy"
     { (yyval.str) = 0; }
     break;
 
   case 54:
 
 /* Line 1455 of yacc.c  */
-#line 531 "../../src/parser.yy"
+#line 547 "../../src/parser.yy"
     { (yyval.str) = (yyvsp[(3) - (3)].str); }
     break;
 
   case 55:
 
 /* Line 1455 of yacc.c  */
-#line 535 "../../src/parser.yy"
+#line 551 "../../src/parser.yy"
     { (yyval.str) = 0; }
     break;
 
   case 56:
 
 /* Line 1455 of yacc.c  */
-#line 536 "../../src/parser.yy"
+#line 552 "../../src/parser.yy"
     { (yyval.str) = (yyvsp[(3) - (3)].str); }
     break;
 
   case 57:
 
 /* Line 1455 of yacc.c  */
-#line 540 "../../src/parser.yy"
+#line 556 "../../src/parser.yy"
     { (yyval.str) = 0; }
     break;
 
   case 58:
 
 /* Line 1455 of yacc.c  */
-#line 541 "../../src/parser.yy"
+#line 557 "../../src/parser.yy"
     { (yyval.str) = (yyvsp[(3) - (3)].str); }
     break;
 
   case 59:
 
 /* Line 1455 of yacc.c  */
-#line 545 "../../src/parser.yy"
+#line 561 "../../src/parser.yy"
     { (yyval.ValueList) = new AcceptedValues; (yyval.ValueList)->insert((yyvsp[(1) - (1)].str)); }
     break;
 
   case 60:
 
 /* Line 1455 of yacc.c  */
-#line 546 "../../src/parser.yy"
+#line 562 "../../src/parser.yy"
     { (yyvsp[(1) - (3)].ValueList)->insert((yyvsp[(3) - (3)].str)); (yyval.ValueList) = (yyvsp[(1) - (3)].ValueList); }
     break;
 
   case 61:
 
 /* Line 1455 of yacc.c  */
-#line 550 "../../src/parser.yy"
+#line 566 "../../src/parser.yy"
     { (yyval.str) = (yyvsp[(1) - (1)].str); }
     break;
 
   case 62:
 
 /* Line 1455 of yacc.c  */
-#line 554 "../../src/parser.yy"
+#line 570 "../../src/parser.yy"
     { (yyval.multiple_size) = new multiple_size; }
     break;
 
   case 63:
 
 /* Line 1455 of yacc.c  */
-#line 555 "../../src/parser.yy"
+#line 571 "../../src/parser.yy"
     { (yyval.multiple_size) = new multiple_size((yyvsp[(2) - (3)].str), (yyvsp[(2) - (3)].str)); }
     break;
 
   case 64:
 
 /* Line 1455 of yacc.c  */
-#line 556 "../../src/parser.yy"
+#line 572 "../../src/parser.yy"
     { (yyval.multiple_size) = new multiple_size((yyvsp[(2) - (4)].str), "0"); free((yyvsp[(2) - (4)].str)); }
     break;
 
   case 65:
 
 /* Line 1455 of yacc.c  */
-#line 557 "../../src/parser.yy"
+#line 573 "../../src/parser.yy"
     { (yyval.multiple_size) = new multiple_size("0", (yyvsp[(3) - (4)].str)); free((yyvsp[(3) - (4)].str)); }
     break;
 
   case 66:
 
 /* Line 1455 of yacc.c  */
-#line 558 "../../src/parser.yy"
+#line 574 "../../src/parser.yy"
     { (yyval.multiple_size) = new multiple_size((yyvsp[(2) - (5)].str), (yyvsp[(4) - (5)].str)); free((yyvsp[(2) - (5)].str)); free((yyvsp[(4) - (5)].str)); }
     break;
 
 
 
 /* Line 1455 of yacc.c  */
-#line 2197 "../../src/parser.cc"
+#line 2213 "../../src/parser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2412,6 +2428,6 @@ yyreturn:
 
 
 /* Line 1675 of yacc.c  */
-#line 561 "../../src/parser.yy"
+#line 577 "../../src/parser.yy"
 
 
